==> arclet_letoderea-0.16.2.tar.gz: arclet_letoderea-0.16.2/tests/test_shorcuts.py <==
import pytest
from typing import Annotated

from arclet.letoderea import bypass_if, enter_if, es, on
from arclet.letoderea.ref import deref


class TestEvent:
    type: str = "TestEvent"
    flag: bool = False
    msg: str

    async def gather(self, context: dict):
        context["flag"] = self.flag
        context["type"] = self.type
        context["msg"] = "hello"


@pytest.mark.asyncio
async def test_annotated():
    executed = []

    @es.on(TestEvent)
    async def s(flag: Annotated[bool, "flag"]):
        assert flag is False
        executed.append(1)

    def func(x): return x["msg"] + "!"

    @es.on(TestEvent)
    async def s1(a: Annotated[str, func]):
        assert a == "hello!"
        executed.append(1)

    e = TestEvent()
    await es.publish(e)
    assert len(executed) == 2


@pytest.mark.asyncio
async def test_deref():
    executed = []

    @on()
    @enter_if(deref(TestEvent).flag)
    async def s(flag: Annotated[bool, "flag"], a: Annotated[str, deref(TestEvent).msg]):
        assert flag is True
        assert a == "hello"
        executed.append(1)

    @on()
    @bypass_if(deref(TestEvent).flag)
    async def s1(
        flag: Annotated[bool, deref(TestEvent).flag],
        t: Annotated[int, deref(TestEvent).type],
        a: Annotated[str, "msg"]
    ):
        assert flag is False
        assert t == "TestEvent"
        assert a == "hello"
        executed.append(1)

    e1 = TestEvent()
    e1.flag = True
    await es.publish(e1)
    e2 = TestEvent()
    await es.publish(e2)
    assert len(executed) == 2

==> arclet_letoderea-0.17.0.tar.gz: arclet_letoderea-0.17.0/tests/test_shorcuts.py <==
import pytest
from typing import Annotated

from arclet.letoderea import bypass_if, enter_if, es, on, on_global
from arclet.letoderea.ref import deref


class ShortcutEvent:
    type: str = "ShortcutEvent"
    flag: bool = False
    msg: str

    async def gather(self, context: dict):
        context["flag"] = self.flag
        context["type"] = self.type
        context["msg"] = "hello"


@pytest.mark.asyncio
async def test_annotated():
    executed = []

    @on(ShortcutEvent)
    async def s(flag: Annotated[bool, "flag"]):
        assert flag is False
        executed.append(1)

    def func(x): return x["msg"] + "!"

    @on(ShortcutEvent)
    async def s1(a: Annotated[str, func]):
        assert a == "hello!"
        executed.append(1)

    e = ShortcutEvent()
    await es.publish(e)
    assert len(executed) == 2


@pytest.mark.asyncio
async def test_deref():
    executed = []

    @on_global
    @enter_if(deref(ShortcutEvent).flag)
    async def s(flag: Annotated[bool, "flag"], a: Annotated[str, deref(ShortcutEvent).msg]):
        assert flag is True
        assert a == "hello"
        executed.append(1)

    @on_global
    @bypass_if(deref(ShortcutEvent).flag)
    async def s1(
        flag: Annotated[bool, deref(ShortcutEvent).flag],
        t: Annotated[int, deref(ShortcutEvent).type],
        a: Annotated[str, "msg"]
    ):
        assert flag is False
        assert t == "ShortcutEvent"
        assert a == "hello"
        executed.append(1)

    e1 = ShortcutEvent()
    e1.flag = True
    await es.publish(e1)
    e2 = ShortcutEvent()
    await es.publish(e2)
    assert len(executed) == 2
